..
    SPDX-License-Identifier: AGPL-3.0-or-later
    Copyright (C) 2025  Dionisis Toulatos

API documentation
#################

    .. rubric:: Here be dragons 🐉

The main library documentation.

.. toctree::
    :hidden:

    api/utils
    api/mqtt
    api/enums
    api/device
    api/comp
